"use strict";
// Copyright (c) Microsoft Corporation.
// Licensed under the MIT License.
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.triggers = exports.makeTriggers = void 0;
const botbuilder_runtime_1 = require("botbuilder-runtime");
// helper function to memoize the result of `func`
function memoize(func) {
    let result;
    return () => {
        result !== null && result !== void 0 ? result : (result = func());
        return result;
    };
}
/**
 * Create azure function triggers using the azure restify integration.
 *
 * @param runtimeServices result of calling `once(() => getRuntimeServices(...))`
 * @returns azure function triggers for `module.exports`
 */
function makeTriggers(runtimeServices) {
    const instances = memoize(() => __awaiter(this, void 0, void 0, function* () {
        const [services] = yield runtimeServices();
        return services.mustMakeInstances('adapter', 'bot', 'channelServiceHandler');
    }));
    return {
        messageTrigger: (context, req) => __awaiter(this, void 0, void 0, function* () {
            context.log('Messages endpoint triggerd.');
            try {
                const { adapter, bot } = yield instances();
                yield adapter.processActivity(req, context.res, (turnContext) => __awaiter(this, void 0, void 0, function* () {
                    yield bot.run(turnContext);
                }));
            }
            catch (err) {
                context.log.error(err);
                throw err;
            }
            context.log('Done.');
        }),
        skillsTrigger: function (context, req) {
            return __awaiter(this, void 0, void 0, function* () {
                context.log('Skill replyToActivity endpoint triggered.');
                try {
                    const { channelServiceHandler: skillHandler } = yield instances();
                    const conversationId = context.bindingData.conversationId;
                    const activityId = context.bindingData.activityId;
                    const authHeader = req.headers.authorization || req.headers.Authorization || '';
                    const result = yield skillHandler.handleReplyToActivity(authHeader, conversationId, activityId, JSON.parse(req.body));
                    const res = context.res;
                    res.status(200);
                    res.send(result);
                    res.end();
                }
                catch (err) {
                    context.log.error(err);
                    throw err;
                }
                context.log('Done.');
            });
        },
    };
}
exports.makeTriggers = makeTriggers;
/**
 * Create azure function triggers using the azure restify integration.
 *
 * @param applicationRoot application root directory
 * @param settingsDirectory settings directory
 * @returns azure function triggers for `module.exports`
 */
function triggers(applicationRoot, settingsDirectory) {
    return makeTriggers(memoize(() => botbuilder_runtime_1.getRuntimeServices(applicationRoot, settingsDirectory)));
}
exports.triggers = triggers;
//# sourceMappingURL=index.js.map